@@ -12,6 +12,7 @@ import sys
 import textwrap
 from types import SimpleNamespace
 import unittest
+from typing import Optional, Union
 
 import littletable as lt
 
@@ -27,6 +28,33 @@ else:
         b: int
         c: int
 
+try:
+    import pydantic
+except ImportError:
+    pydantic = None
+else:
+    class DataPydanticModel(pydantic.BaseModel):
+        a: Optional[Union[int, str]]
+        b: Optional[Union[int, str]]
+        c: Optional[Union[int, str]]
+
+    class DataPydanticImmutableModel(pydantic.BaseModel):
+        class Config:
+            allow_mutation = False
+
+        a: Optional[Union[int, str]]
+        b: Optional[Union[int, str]]
+        c: Optional[Union[int, str]]
+
+    class DataPydanticORMModel(pydantic.BaseModel):
+        class Config:
+            orm_mode = True
+
+        a: Optional[Union[int, str]]
+        b: Optional[Union[int, str]]
+        c: Optional[Union[int, str]]
+
+
 DataTuple = namedtuple("DataTuple", "a b c")
 
 # if rich is not installed, disable table.present() calls
@@ -49,7 +77,7 @@ class Slotted(object):
     def __eq__(self, other):
         return (isinstance(other, Slotted) and
                 all(getattr(self, attr) == getattr(other, attr) for attr in self.__slots__))
-    
+
     def __repr__(self):
         return "{}:(a={}, b={}, c={})".format(type(self).__name__, self.a, self.b, self.c)
 
@@ -91,11 +119,11 @@ class TestDataObjects(unittest.TestCase):
 
 class TestTableTypes(unittest.TestCase):
     def test_types(self):
-        
+
         # check that Table and Index are recognized as Sequence and Mapping types
         t = lt.Table()
         self.assertTrue(isinstance(t, lt.Sequence))
-        
+
         t.create_index("x")
         self.assertTrue(isinstance(t.get_index('x'), lt.Mapping))
 
@@ -134,10 +162,14 @@ def make_test_classes(cls):
     make_test_class(cls, UsingSimpleNamespace)
     if dataclasses is not None:
         make_test_class(cls, UsingDataclasses)
+    if pydantic is not None:
+        make_test_class(cls, UsingPydanticModel)
+        make_test_class(cls, UsingPydanticImmutableModel)
+        make_test_class(cls, UsingPydanticORMModel)
 
 
 class AbstractContentTypeFactory:
-    data_object_type = None
+    data_object_type: Optional[type] = None
 
     @classmethod
     def make_data_object(cls, a, b, c):
@@ -159,6 +191,7 @@ class UsingSlottedObjects(AbstractContentTypeFactory):
 class UsingSimpleNamespace(AbstractContentTypeFactory):
     data_object_type = SimpleNamespace
 
+
 if dataclasses is not None:
     class UsingDataclasses(AbstractContentTypeFactory):
         data_object_type = DataDataclass
@@ -166,6 +199,22 @@ else:
     UsingDataclasses = AbstractContentTypeFactory
 
 
+if pydantic is not None:
+    class UsingPydanticModel(AbstractContentTypeFactory):
+        data_object_type = DataPydanticModel
+
+    class UsingPydanticImmutableModel(AbstractContentTypeFactory):
+        data_object_type = DataPydanticImmutableModel
+
+    class UsingPydanticORMModel(AbstractContentTypeFactory):
+        data_object_type = DataPydanticORMModel
+
+else:
+    UsingPydanticModel = AbstractContentTypeFactory
+    UsingPydanticImmutableModel = AbstractContentTypeFactory
+    UsingPydanticORMModel = AbstractContentTypeFactory
+
+
 def load_table(table, rec_factory_fn, table_size):
     test_size = table_size
     for aa, bb, cc in itertools.product(range(test_size), repeat=3):
@@ -557,7 +606,7 @@ class TableListTests:
         self._test_init()
         self.t1.create_index("a")
         self.t1.create_index("c")
-        self.assertEqual(set(["a", "c"]), set(self.t1._indexes.keys()), "failed to create indexes")
+        self.assertEqual({"a", "c"}, set(self.t1._indexes.keys()), "failed to create indexes")
 
         self.assertEqual(set(self.t1._indexes.keys()),
                          set(self.t1.head()._indexes.keys()),
@@ -990,6 +1039,24 @@ class TableTransformTests:
 
         self.assertEqual(t1_tuples, t2_tuples, "failed mixed ascending/descending multi-attribute sort")
 
+    def test_sort3(self):
+        employees = lt.Table().csv_import(textwrap.dedent("""\
+            emp_id,name,dept,salary,commission
+            0001,Alice,Sales,50000,0.5
+            0002,Bob,Engineering,100000,
+            0003,Charles,Sales,45000,0.7
+            0004,Dave,Sales,45000,0.6
+            0005,Emily,Sales,50000,0.4
+            """), transforms={"salary": int, "commission": float})
+
+        sales_employees = employees.where(dept="Sales").sort("salary desc,commission")
+
+        sales_employees.present()
+        print(list(sales_employees.all.emp_id))
+
+        self.assertEqual(['0005', '0001', '0004', '0003'],
+                         list(sales_employees.all.emp_id))
+
     def test_unique(self):
         test_size = 10
         t1 = make_test_table(self.make_data_object, test_size)
